@@ -319,11 +319,11 @@ class DevTitleBar(tk.Frame):
 
         if self.iswindow:
             if self.close:
-                self.closebutton.configure(command=self.window_close)
+                self.closebutton.configure(command=self.widget_close)
             if self.max:
-                self.maxbutton.configure(command=self.window_max)
+                self.maxbutton.configure(command=self.widget_max)
             if self.min:
-                self.minbutton.configure(command=self.window_min)
+                self.minbutton.configure(command=self.widget_min)
         else:
             if self.close:
                 self.closebutton.configure(command=self.widget_close)
@@ -351,13 +351,13 @@ class DevTitleBar(tk.Frame):
                                    activeforeground="#ffffff")
         self.minbutton.pack(fill=tk.Y, side=self.button_side, ipadx=8)
 
-    def window_close(self):
+    def widget_close(self):
         if self.iswindow:
             self.window.destroy()
         elif not self.iswindow:
             self.widget.destroy()
 
-    def window_max(self):
+    def widget_max(self):
         if self.iswindow:
             if self.ismax:
                 self.window.geometry(f"{self._width}x{self._height}+{self._x}+{self._y}")
@@ -375,39 +375,21 @@ class DevTitleBar(tk.Frame):
             self.window.update()
         if not self.iswindow:
             if self.ismax:
-                self.widget.geometry(f"{self._width}x{self._height}+{self._x}+{self._y}")
+                self.widget.place(width=self._width, height=self._height, x=self._x, y=self._y)
                 self.ismax = False
             elif not self.ismax:
                 self._x = self.widget.winfo_x()
                 self._y = self.widget.winfo_y()
                 self._width = self.widget.winfo_width()
                 self._height = self.widget.winfo_height()
-                self.widget.place(width=self.master.winfo_width(), height=self.master.winfo_height())
-                self.window.attributes('-topmost', 1)
-                self.window.attributes('-topmost', 0)
-                self.window.place(x=0, y=0)
+                self.widget.place(width=self.widget.master.winfo_width(), height=self.widget.master.winfo_height(), x=0, y=0)
+                self.widget.place(x=0, y=0)
                 self.ismax = True
-            self.window.update()
+            self.widget.update()
         self.update()
 
-    def window_min(self):
-        pass
-
-    def widget_close(self):
-        if self.iswindow:
-            self.window.destroy()
-        elif self.iswindow:
-            self.widget.destroy()
-
-    def widget_max(self):
-        self._x = self.widget.winfo_x()
-        self._y = self.widget.winfo_y()
-        self._width = self.widget.winfo_width()
-        self._height = self.widget.winfo_height()
-        self.widget.place(x=0, y=0, width=self.widget.master.winfo_width(), height=self.widget.master.winfo_height())
-
     def widget_min(self):
-        self.widget.place(x=self._x, y=self._y, width=self._width, height=self._height)
+        pass
 
     def show(self):
         self.pack(fill=tk.X, side=tk.TOP)
